@@ -7,11 +7,12 @@ Two ways to implement a converter
 .. index:: syntax
 
 There are two ways to write a converter. The first one
-is very verbose (see `ada_boost.py <https://github.com/onnx/
-sklearn-onnx/blob/master/skl2onnx/operator_converters/ada_boost.py>`_
-for an example). The other is less verbose and easier to understand
+is less verbose and easier to understand
 (see `k_means.py <https://github.com/onnx/sklearn-onnx/blob/
 master/skl2onnx/operator_converters/k_means.py>`_).
+The other is very verbose (see `ada_boost.py <https://github.com/onnx/
+sklearn-onnx/blob/master/skl2onnx/operator_converters/ada_boost.py>`_
+for an example).
 
 The first way is used in :ref:`l-plot-custom-converter`.
 This one demonstrates the second way which is usually the one
