@@ -122,6 +122,12 @@ class _WhiteBlackContainer:
                 raise RuntimeError(
                     "Operator '{}' is black listed.".format(node_type))
 
+    def debug(self, *args, **kwargs):
+        """
+        Log debug information while converting a model.
+        """
+        logger.debug(*args, **kwargs)
+
 
 class RawModelContainerNode(_WhiteBlackContainer):
     """
@@ -416,7 +422,7 @@ class ModelComponentContainer(_WhiteBlackContainer):
                         or a float array).
         :return: created tensor
         """
-        logger.debug("[Init] %r, %r, %r" % (name, onnx_type, shape))
+        logger.debug("[Init] %r, %r, %r", name, onnx_type, shape)
         sparse_tensor = None
         tensor = None
 
@@ -581,8 +587,9 @@ class ModelComponentContainer(_WhiteBlackContainer):
             inputs = [inputs]
         if isinstance(outputs, str):
             outputs = [outputs]
-        logger.debug("[Node] %r - %r -> %r (name=%r)" % (
-            op_type, ",".join(inputs), ",".join(outputs), name))
+        logger.debug(
+            "[Node] %r - %r -> %r (name=%r)",
+            op_type, ",".join(inputs), ",".join(outputs), name)
         try:
             common = set(inputs) & set(outputs)
         except TypeError as e:
