@@ -15,7 +15,7 @@ from ..common.tree_ensemble import (
     get_default_tree_regressor_attribute_pairs)
 from ..proto import onnx_proto
 from ..algebra.onnx_ops import (
-    OnnxTreeEnsembleRegressor, OnnxLog,
+    OnnxTreeEnsembleRegressor_1, OnnxLog,
     OnnxCast, OnnxLess, OnnxLabelEncoder, OnnxMul,
     OnnxGreater, OnnxAdd, OnnxDiv, OnnxSum, OnnxNeg,
     OnnxReshapeApi13, OnnxEqual, OnnxPow, OnnxGather, OnnxMax)
@@ -65,7 +65,7 @@ def convert_sklearn_isolation_forest(
         attrs['post_transform'] = 'NONE'
         attrs['target_ids'] = [0 for _ in attrs['target_ids']]
         attrs['target_weights'] = [float(_) for _ in attrs['target_nodeids']]
-        leave = OnnxTreeEnsembleRegressor(gather, op_version=opv, **attrs)
+        leave = OnnxTreeEnsembleRegressor_1(gather, op_version=1, **attrs)
 
         # tree - retrieve node_sample
         labels = _build_labels(tree.tree_, output="node_sample")
