@@ -1,6 +1,7 @@
 # SPDX-License-Identifier: Apache-2.0
 
 from sklearn.base import is_regressor
+from sklearn.svm import LinearSVC
 from ..proto import onnx_proto
 from ..common._apply_operation import (
     apply_concat, apply_identity, apply_mul, apply_reshape)
@@ -15,6 +16,45 @@ from ..common.data_types import guess_proto_type, Int64TensorType
 from .._supported_operators import sklearn_operator_name_map
 
 
+def _iteration_one_versus(scope, container, inputs, i, estimator, cl_type,
+                          proto_dtype, use_raw_scores=True, prob_shape=None):
+    op_type = sklearn_operator_name_map[type(estimator)]
+
+    this_operator = scope.declare_local_operator(
+        op_type, raw_model=estimator)
+    this_operator.inputs = inputs
+
+    if is_regressor(estimator):
+        score_name = scope.declare_local_variable('score_%d' % i, cl_type())
+        this_operator.outputs.append(score_name)
+
+        if hasattr(estimator, 'coef_') and len(estimator.coef_.shape) == 2:
+            raise RuntimeError(
+                "OneVsRestClassifier or OneVsOneClassifier accepts "
+                "regressor with only one target.")
+        p1 = score_name.onnx_name
+    else:
+        if container.has_options(estimator, 'raw_scores'):
+            container.add_options(
+                id(estimator), {'raw_scores': use_raw_scores})
+            scope.add_options(
+                id(estimator), {'raw_scores': use_raw_scores})
+        label_name = scope.declare_local_variable(
+            'label_%d' % i, Int64TensorType())
+        prob_name = scope.declare_local_variable('proba_%d' % i, cl_type())
+        this_operator.outputs.append(label_name)
+        this_operator.outputs.append(prob_name)
+
+        # gets the probability for the class 1
+        p1 = scope.get_unique_variable_name('probY_%d' % i)
+        if isinstance(estimator, LinearSVC):
+            apply_identity(scope, prob_name.onnx_name, p1, container)
+        else:
+            apply_slice(scope, prob_name.onnx_name, p1, container, starts=[1],
+                        ends=[2], axes=[1])
+    return None, None, p1
+
+
 def convert_one_vs_rest_classifier(scope: Scope, operator: Operator,
                                    container: ModelComponentContainer):
     """
@@ -31,41 +71,12 @@ def convert_one_vs_rest_classifier(scope: Scope, operator: Operator,
     options = container.get_options(op, dict(raw_scores=False))
     use_raw_scores = options['raw_scores']
     probs_names = []
+    cl_type = operator.inputs[0].type.__class__
+    prob_shape = None
     for i, estimator in enumerate(op.estimators_):
-        op_type = sklearn_operator_name_map[type(estimator)]
-
-        this_operator = scope.declare_local_operator(
-            op_type, raw_model=estimator)
-        this_operator.inputs = operator.inputs
-
-        if is_regressor(estimator):
-            score_name = scope.declare_local_variable(
-                'score_%d' % i, operator.inputs[0].type.__class__())
-            this_operator.outputs.append(score_name)
-
-            if hasattr(estimator, 'coef_') and len(estimator.coef_.shape) == 2:
-                raise RuntimeError("OneVsRestClassifier accepts "
-                                   "regressor with only one target.")
-            p1 = score_name.onnx_name
-        else:
-            if container.has_options(estimator, 'raw_scores'):
-                container.add_options(
-                    id(estimator), {'raw_scores': use_raw_scores})
-                scope.add_options(
-                    id(estimator), {'raw_scores': use_raw_scores})
-            label_name = scope.declare_local_variable(
-                'label_%d' % i, Int64TensorType())
-            prob_name = scope.declare_local_variable(
-                'proba_%d' % i, operator.inputs[0].type.__class__())
-            this_operator.outputs.append(label_name)
-            this_operator.outputs.append(prob_name)
-
-            # gets the probability for the class 1
-            p1 = scope.get_unique_variable_name('probY_%d' % i)
-            apply_slice(scope, prob_name.onnx_name, p1, container, starts=[1],
-                        ends=[2], axes=[1],
-                        operator_name=scope.get_unique_operator_name('Slice'))
-
+        prob_shape, _, p1 = _iteration_one_versus(
+            scope, container, operator.inputs, i, estimator, cl_type,
+            proto_dtype, use_raw_scores, prob_shape=prob_shape)
         probs_names.append(p1)
 
     if op.multilabel_:
@@ -165,4 +176,5 @@ register_converter('SklearnOneVsRestClassifier',
                    convert_one_vs_rest_classifier,
                    options={'zipmap': [True, False, 'columns'],
                             'nocl': [True, False],
+                            'output_class_labels': [False, True],
                             'raw_scores': [True, False]})
