@@ -2,7 +2,7 @@
 
 import unittest
 import warnings
-from distutils.version import StrictVersion
+import packaging.version as pv
 from collections import OrderedDict
 import numpy as np
 from numpy.testing import assert_almost_equal
@@ -10,6 +10,12 @@ from scipy.spatial.distance import pdist, squareform, cdist as scipy_cdist
 import onnx
 from onnx.onnx_cpp2py_export.checker import ValidationError
 from onnxruntime import InferenceSession, __version__ as ort_version
+try:
+    # scikit-learn >= 0.22
+    from sklearn.utils._testing import ignore_warnings
+except ImportError:
+    # scikit-learn < 0.22
+    from sklearn.utils.testing import ignore_warnings
 from skl2onnx.common.data_types import FloatTensorType
 from skl2onnx.algebra.onnx_ops import (
     OnnxAdd, OnnxIdentity, OnnxScan,
@@ -22,12 +28,9 @@ except ImportError:
     # onnx is too old
     OnnxConstantOfShape = None
 from onnx import (
-    helper, TensorProto,
-    __version__ as onnx__version__
-)
+    helper, TensorProto, __version__ as onnx__version__)
 from skl2onnx.algebra.complex_functions import (
-    onnx_squareform_pdist, onnx_cdist
-)
+    onnx_squareform_pdist, onnx_cdist)
 from skl2onnx.proto import get_latest_tested_opset_version
 from test_utils import TARGET_OPSET, TARGET_IR
 
@@ -36,14 +39,15 @@ _TARGET_OPSET_ = min(get_latest_tested_opset_version(), TARGET_OPSET)
 
 THRESHOLD = "0.4.0"
 THRESHOLD2 = "0.5.0"
+ort_version = ".".join(ort_version.split('.')[:2])
 
 
 class TestOnnxOperatorsScan(unittest.TestCase):
 
-    @unittest.skipIf(StrictVersion(onnx__version__) < StrictVersion("1.4.0"),
-                     reason="only available for opset >= 10")
-    @unittest.skipIf(StrictVersion(ort_version) <= StrictVersion(THRESHOLD),
+    @unittest.skipIf(TARGET_OPSET < 10, reason="not available")
+    @unittest.skipIf(pv.Version(ort_version) <= pv.Version(THRESHOLD),
                      reason="fails with onnxruntime 0.4.0")
+    @ignore_warnings(category=DeprecationWarning)
     def test_onnx_example(self):
         sum_in = onnx.helper.make_tensor_value_info(
             'sum_in', onnx.TensorProto.FLOAT, [2])
@@ -91,6 +95,7 @@ class TestOnnxOperatorsScan(unittest.TestCase):
         )
 
         model_def = helper.make_model(graph_def, producer_name='onnx-example')
+        del model_def.opset_import[:]
         op_set = model_def.opset_import.add()
         op_set.domain = ''
         op_set.version = TARGET_OPSET
@@ -116,10 +121,10 @@ class TestOnnxOperatorsScan(unittest.TestCase):
         assert_almost_equal(y, res[0])
         assert_almost_equal(z, res[1])
 
-    @unittest.skipIf(StrictVersion(onnx__version__) < StrictVersion("1.4.0"),
-                     reason="only available for opset >= 10")
-    @unittest.skipIf(StrictVersion(ort_version) <= StrictVersion(THRESHOLD),
+    @unittest.skipIf(TARGET_OPSET < 10, reason="not available")
+    @unittest.skipIf(pv.Version(ort_version) <= pv.Version(THRESHOLD),
                      reason="fails with onnxruntime 0.4.0")
+    @ignore_warnings(category=DeprecationWarning)
     def test_onnx_example_algebra(self):
         initial = np.array([0, 0]).astype(np.float32).reshape((2,))
         x = np.array([1, 2, 3, 4, 5, 6]).astype(np.float32).reshape((3, 2))
@@ -152,10 +157,10 @@ class TestOnnxOperatorsScan(unittest.TestCase):
         assert_almost_equal(y, res[0])
         assert_almost_equal(z, res[1])
 
-    @unittest.skipIf(StrictVersion(onnx__version__) < StrictVersion("1.4.0"),
-                     reason="only available for opset >= 10")
-    @unittest.skipIf(StrictVersion(ort_version) <= StrictVersion(THRESHOLD),
+    @unittest.skipIf(TARGET_OPSET < 10, reason="not available")
+    @unittest.skipIf(pv.Version(ort_version) <= pv.Version(THRESHOLD),
                      reason="fails with onnxruntime 0.4.0")
+    @ignore_warnings(category=DeprecationWarning)
     def test_onnx_example_pdist(self):
         x = np.array([1, 2, 4, 5, 5, 4]).astype(np.float32).reshape((3, 2))
 
@@ -194,7 +199,7 @@ class TestOnnxOperatorsScan(unittest.TestCase):
         try:
             onnx.checker.check_model(model_def)
         except ValidationError as e:
-            if StrictVersion(onnx__version__) <= StrictVersion("1.5.0"):
+            if pv.Version(onnx__version__) <= pv.Version("1.5.0"):
                 warnings.warn(e)
             else:
                 raise e
@@ -206,10 +211,10 @@ class TestOnnxOperatorsScan(unittest.TestCase):
         assert_almost_equal(x, res[0])
         assert_almost_equal(exp, res[1])
 
-    @unittest.skipIf(StrictVersion(onnx__version__) < StrictVersion("1.4.0"),
-                     reason="only available for opset >= 10")
-    @unittest.skipIf(StrictVersion(ort_version) <= StrictVersion(THRESHOLD),
+    @unittest.skipIf(TARGET_OPSET < 10, reason="not available")
+    @unittest.skipIf(pv.Version(ort_version) <= pv.Version(THRESHOLD),
                      reason="fails with onnxruntime 0.4.0")
+    @ignore_warnings(category=DeprecationWarning)
     def test_onnx_example_pdist_in(self):
         opv = _TARGET_OPSET_
         x = np.array([1, 2, 4, 5, 5, 4]).astype(np.float32).reshape((3, 2))
@@ -245,8 +250,9 @@ class TestOnnxOperatorsScan(unittest.TestCase):
         assert_almost_equal(exp, res[0])
 
     @unittest.skipIf((OnnxConstantOfShape is None or
-                      StrictVersion(ort_version) <= StrictVersion(THRESHOLD)),
+                      pv.Version(ort_version) <= pv.Version(THRESHOLD)),
                      reason="fails with onnxruntime 0.4.0")
+    @ignore_warnings(category=DeprecationWarning)
     def test_onnx_example_constant_of_shape(self):
         x = np.array([1, 2, 4, 5, 5, 4]).astype(np.float32).reshape((3, 2))
 
@@ -274,10 +280,10 @@ class TestOnnxOperatorsScan(unittest.TestCase):
         exp = np.full((3, 2), -5.)
         assert_almost_equal(exp, res[0])
 
-    @unittest.skipIf(StrictVersion(onnx__version__) < StrictVersion("1.4.0"),
-                     reason="only available for opset >= 10")
-    @unittest.skipIf(StrictVersion(ort_version) <= StrictVersion(THRESHOLD),
+    @unittest.skipIf(TARGET_OPSET < 10, reason="not available")
+    @unittest.skipIf(pv.Version(ort_version) <= pv.Version(THRESHOLD),
                      reason="fails with onnxruntime 0.4.0")
+    @ignore_warnings(category=DeprecationWarning)
     def test_onnx_example_cdist_in(self):
         x = np.array([1, 2, 4, 5, 5, 4]).astype(np.float32).reshape((3, 2))
         x2 = np.array([1.1, 2.1, 4.01, 5.01, 5.001, 4.001, 0, 0]).astype(
@@ -323,10 +329,10 @@ class TestOnnxOperatorsScan(unittest.TestCase):
         assert_almost_equal(exp, res[0], decimal=4)
         assert "u_scan0_" not in str(model_def)
 
-    @unittest.skipIf(StrictVersion(onnx__version__) < StrictVersion("1.4.0"),
-                     reason="only available for opset >= 10")
-    @unittest.skipIf(StrictVersion(ort_version) <= StrictVersion(THRESHOLD2),
+    @unittest.skipIf(TARGET_OPSET < 10, reason="not available")
+    @unittest.skipIf(pv.Version(ort_version) <= pv.Version(THRESHOLD2),
                      reason="fails with onnxruntime 0.4.0")
+    @ignore_warnings(category=DeprecationWarning)
     def test_onnx_example_cdist_in_mink(self):
         x = np.array([1, 2, 4, 5, 5, 4]).astype(np.float32).reshape((3, 2))
         x2 = np.array([1.1, 2.1, 4.01, 5.01, 5.001, 4.001, 0, 0]).astype(
@@ -375,10 +381,10 @@ class TestOnnxOperatorsScan(unittest.TestCase):
         exp = scipy_cdist(x * 2, x, metric="sqeuclidean")
         assert_almost_equal(exp, res[0], decimal=4)
 
-    @unittest.skipIf(StrictVersion(onnx__version__) < StrictVersion("1.5.0"),
-                     reason="only available for opset >= 10")
-    @unittest.skipIf(StrictVersion(ort_version) <= StrictVersion(THRESHOLD2),
+    @unittest.skipIf(TARGET_OPSET < 10, reason="not available")
+    @unittest.skipIf(pv.Version(ort_version) <= pv.Version(THRESHOLD2),
                      reason="fails with onnxruntime 0.4.0")
+    @ignore_warnings(category=DeprecationWarning)
     def test_onnx_example_cdist_in_custom_ops(self):
         x = np.array([1, 2, 4, 5, 5, 4]).astype(np.float32).reshape((3, 2))
         x2 = np.array([1.1, 2.1, 4.01, 5.01, 5.001, 4.001, 0, 0]).astype(
