@@ -2,7 +2,7 @@
 
 
 import unittest
-from distutils.version import StrictVersion
+import packaging.version as pv
 import onnxruntime
 try:
     # scikit-learn >= 0.22
@@ -58,10 +58,7 @@ class TestSklearnBaggingConverter(unittest.TestCase):
             X,
             model,
             model_onnx,
-            basename="SklearnBaggingClassifierDefaultMulticlass",
-            allow_failure="StrictVersion(onnxruntime.__version__)"
-            "<= StrictVersion('0.2.1')",
-        )
+            basename="SklearnBaggingClassifierDefaultMulticlass")
 
     @ignore_warnings(category=FutureWarning)
     def test_bagging_classifier_default_binary(self):
@@ -78,10 +75,7 @@ class TestSklearnBaggingConverter(unittest.TestCase):
             X,
             model,
             model_onnx,
-            basename="SklearnBaggingClassifierDefaultBinary",
-            allow_failure="StrictVersion(onnxruntime.__version__)"
-            "<= StrictVersion('0.2.1')",
-        )
+            basename="SklearnBaggingClassifierDefaultBinary")
 
     @ignore_warnings(category=FutureWarning)
     def test_bagging_classifier_max_features(self):
@@ -94,9 +88,7 @@ class TestSklearnBaggingConverter(unittest.TestCase):
         self.assertIsNotNone(model_onnx)
         dump_data_and_model(
             X, model, model_onnx, verbose=False,
-            basename="SklearnBaggingClassifierMaxFeatures",
-            allow_failure="StrictVersion(onnxruntime.__version__)"
-            "<= StrictVersion('0.2.1')")
+            basename="SklearnBaggingClassifierMaxFeatures")
 
     @ignore_warnings(category=FutureWarning)
     def test_bagging_classifier_bootstrap_features(self):
@@ -109,9 +101,7 @@ class TestSklearnBaggingConverter(unittest.TestCase):
         self.assertIsNotNone(model_onnx)
         dump_data_and_model(
             X[:5], model, model_onnx, verbose=False,
-            basename="SklearnBaggingClassifierBootstrapFeatures",
-            allow_failure="StrictVersion(onnxruntime.__version__)"
-            "<= StrictVersion('0.2.1')")
+            basename="SklearnBaggingClassifierBootstrapFeatures")
 
     @ignore_warnings(category=FutureWarning)
     def test_bagging_classifier_default_binary_nozipmap(self):
@@ -125,9 +115,7 @@ class TestSklearnBaggingConverter(unittest.TestCase):
         self.assertIsNotNone(model_onnx)
         dump_data_and_model(
             X, model, model_onnx,
-            basename="SklearnBaggingClassifierDefaultBinaryNoZipMap",
-            allow_failure="StrictVersion(onnxruntime.__version__)"
-            "<= StrictVersion('0.2.1')")
+            basename="SklearnBaggingClassifierDefaultBinaryNoZipMap")
 
     @ignore_warnings(category=FutureWarning)
     def test_bagging_classifier_default_multiclass(self):
@@ -144,10 +132,7 @@ class TestSklearnBaggingConverter(unittest.TestCase):
             X,
             model,
             model_onnx,
-            basename="SklearnBaggingClassifierDefaultMulticlass",
-            allow_failure="StrictVersion(onnxruntime.__version__)"
-            "<= StrictVersion('0.2.1')",
-        )
+            basename="SklearnBaggingClassifierDefaultMulticlass")
 
     @ignore_warnings(category=FutureWarning)
     def test_bagging_classifier_sgd_binary(self):
@@ -166,10 +151,7 @@ class TestSklearnBaggingConverter(unittest.TestCase):
             X,
             model,
             model_onnx,
-            basename="SklearnBaggingClassifierSGDBinary",
-            allow_failure="StrictVersion(onnxruntime.__version__)"
-            "<= StrictVersion('0.2.1')",
-        )
+            basename="SklearnBaggingClassifierSGDBinary")
 
     @ignore_warnings(category=FutureWarning)
     def test_bagging_classifier_sgd_binary_decision_function(self):
@@ -188,12 +170,10 @@ class TestSklearnBaggingConverter(unittest.TestCase):
         dump_data_and_model(
             X[:5], model, model_onnx,
             basename="SklearnBaggingClassifierSGDBinaryDecisionFunction-Dec3",
-            allow_failure="StrictVersion(onnxruntime.__version__)"
-            "<= StrictVersion('0.2.1')",
             methods=['predict', 'decision_function_binary'])
 
-    @unittest.skipIf(StrictVersion(onnxruntime.__version__)
-                     <= StrictVersion("0.4.0"),
+    @unittest.skipIf(pv.Version(onnxruntime.__version__)
+                     <= pv.Version("0.4.0"),
                      reason="Not implemented.")
     @ignore_warnings(category=FutureWarning)
     def test_bagging_classifier_sgd_multiclass(self):
@@ -210,9 +190,7 @@ class TestSklearnBaggingConverter(unittest.TestCase):
         self.assertIsNotNone(model_onnx)
         dump_data_and_model(
             X[:5], model, model_onnx,
-            basename="SklearnBaggingClassifierSGDMulticlass-Dec3",
-            allow_failure="StrictVersion(onnxruntime.__version__)"
-            "<= StrictVersion('0.2.1')")
+            basename="SklearnBaggingClassifierSGDMulticlass-Dec3")
 
     @ignore_warnings(category=FutureWarning)
     def test_bagging_classifier_sgd_multiclass_decision_function(self):
@@ -230,8 +208,6 @@ class TestSklearnBaggingConverter(unittest.TestCase):
         dump_data_and_model(
             X[:15], model, model_onnx,
             basename="SklearnBaggingClassifierSGDMultiDecisionFunction-Dec3",
-            allow_failure="StrictVersion(onnxruntime.__version__)"
-            "<= StrictVersion('0.2.1')",
             methods=['predict', 'decision_function'])
 
     @ignore_warnings(category=FutureWarning)
@@ -250,10 +226,7 @@ class TestSklearnBaggingConverter(unittest.TestCase):
             X,
             model,
             model_onnx,
-            basename="SklearnBaggingClassifierGradientBoostingBinary",
-            allow_failure="StrictVersion(onnxruntime.__version__)"
-            "<= StrictVersion('0.2.1')",
-        )
+            basename="SklearnBaggingClassifierGradientBoostingBinary")
 
     @ignore_warnings(category=FutureWarning)
     def test_bagging_classifier_gradient_boosting_multiclass(self):
@@ -271,10 +244,7 @@ class TestSklearnBaggingConverter(unittest.TestCase):
             X,
             model,
             model_onnx,
-            basename="SklearnBaggingClassifierGradientBoostingMulticlass",
-            allow_failure="StrictVersion(onnxruntime.__version__)"
-            "<= StrictVersion('0.2.1')",
-        )
+            basename="SklearnBaggingClassifierGradientBoostingMulticlass")
 
     @ignore_warnings(category=FutureWarning)
     def test_bagging_regressor_default(self):
@@ -291,10 +261,7 @@ class TestSklearnBaggingConverter(unittest.TestCase):
             X,
             model,
             model_onnx,
-            basename="SklearnBaggingRegressorDefault-Dec4",
-            allow_failure="StrictVersion(onnxruntime.__version__)"
-            "<= StrictVersion('0.2.1')",
-        )
+            basename="SklearnBaggingRegressorDefault-Dec4")
 
     @ignore_warnings(category=FutureWarning)
     def test_bagging_regressor_max_features(self):
@@ -307,9 +274,7 @@ class TestSklearnBaggingConverter(unittest.TestCase):
         self.assertIsNotNone(model_onnx)
         dump_data_and_model(
             X, model, model_onnx, verbose=False,
-            basename="SklearnBaggingRegressorMaxFeatures-Dec4",
-            allow_failure="StrictVersion(onnxruntime.__version__)"
-            "<= StrictVersion('0.2.1')")
+            basename="SklearnBaggingRegressorMaxFeatures-Dec4")
 
     def test_bagging_regressor_bootstrap_features(self):
         model, X = fit_regression_model(
@@ -321,9 +286,7 @@ class TestSklearnBaggingConverter(unittest.TestCase):
         self.assertIsNotNone(model_onnx)
         dump_data_and_model(
             X, model, model_onnx, verbose=False,
-            basename="SklearnBaggingRegressorBootstrapFeatures-Dec4",
-            allow_failure="StrictVersion(onnxruntime.__version__)"
-            "<= StrictVersion('0.2.1')")
+            basename="SklearnBaggingRegressorBootstrapFeatures-Dec4")
 
     @ignore_warnings(category=FutureWarning)
     def test_bagging_regressor_sgd(self):
@@ -338,10 +301,7 @@ class TestSklearnBaggingConverter(unittest.TestCase):
             X,
             model,
             model_onnx,
-            basename="SklearnBaggingRegressorSGD-Dec4",
-            allow_failure="StrictVersion(onnxruntime.__version__)"
-            "<= StrictVersion('0.2.1')",
-        )
+            basename="SklearnBaggingRegressorSGD-Dec4")
 
     @ignore_warnings(category=FutureWarning)
     def test_bagging_regressor_gradient_boosting(self):
@@ -355,9 +315,7 @@ class TestSklearnBaggingConverter(unittest.TestCase):
         self.assertIsNotNone(model_onnx)
         dump_data_and_model(
             X, model, model_onnx,
-            basename="SklearnBaggingRegressorGradientBoosting-Dec4",
-            allow_failure="StrictVersion(onnxruntime.__version__)"
-            "<= StrictVersion('0.2.1')")
+            basename="SklearnBaggingRegressorGradientBoosting-Dec4")
 
     @ignore_warnings(category=FutureWarning)
     def test_bagging_regressor_bool(self):
@@ -374,10 +332,7 @@ class TestSklearnBaggingConverter(unittest.TestCase):
             X,
             model,
             model_onnx,
-            basename="SklearnBaggingRegressorBool-Dec4",
-            allow_failure="StrictVersion(onnxruntime.__version__)"
-            "<= StrictVersion('0.2.1')",
-        )
+            basename="SklearnBaggingRegressorBool-Dec4")
 
 
 if __name__ == "__main__":
