@@ -17,7 +17,6 @@ except ImportError:
     OrtFail = RuntimeError
 from skl2onnx import convert_sklearn, to_onnx
 from skl2onnx.common.data_types import FloatTensorType
-from skl2onnx.common.data_types import onnx_built_with_ml
 from test_utils import dump_data_and_model, TARGET_OPSET
 
 
@@ -56,8 +55,6 @@ class TestGaussianMixtureConverter(unittest.TestCase):
         np.testing.assert_almost_equal(
             exp.ravel(), got[2].ravel(), decimal=decimal)
 
-    @unittest.skipIf(not onnx_built_with_ml(),
-                     reason="Requires ONNX-ML extension.")
     @unittest.skipIf(TARGET_OPSET < 11,
                      reason="Missing Gemm (11)")
     @ignore_warnings(category=UserWarning)
@@ -73,9 +70,7 @@ class TestGaussianMixtureConverter(unittest.TestCase):
                 self.assertIsNotNone(model_onnx)
                 dump_data_and_model(
                     X, model, model_onnx,
-                    basename="SklearnBinGaussianMixture",
-                    allow_failure="StrictVersion(onnxruntime.__version__)"
-                    "<= StrictVersion('0.2.1')")
+                    basename="SklearnBinGaussianMixture")
                 self._test_score(model, X, tg)
 
     @ignore_warnings(category=UserWarning)
@@ -96,14 +91,9 @@ class TestGaussianMixtureConverter(unittest.TestCase):
                     X,
                     model,
                     model_onnx,
-                    basename="SklearnBinBayesianGaussianMixture",
-                    allow_failure="StrictVersion(onnxruntime.__version__)"
-                    "<= StrictVersion('0.2.1')",
-                )
+                    basename="SklearnBinBayesianGaussianMixture")
                 self._test_score(model, X, TARGET_OPSET)
 
-    @unittest.skipIf(not onnx_built_with_ml(),
-                     reason="Requires ONNX-ML extension.")
     @ignore_warnings(category=UserWarning)
     def test_model_gaussian_mixture_multiclass(self):
         model, X = self._fit_model_multiclass_classification(
@@ -119,14 +109,9 @@ class TestGaussianMixtureConverter(unittest.TestCase):
             X,
             model,
             model_onnx,
-            basename="SklearnMclGaussianMixture",
-            allow_failure="StrictVersion(onnxruntime.__version__)"
-            "<= StrictVersion('0.2.1')",
-        )
+            basename="SklearnMclGaussianMixture")
         self._test_score(model, X, TARGET_OPSET)
 
-    @unittest.skipIf(not onnx_built_with_ml(),
-                     reason="Requires ONNX-ML extension.")
     @ignore_warnings(category=UserWarning)
     def test_gaussian_mixture_comp2(self):
         data = load_iris()
@@ -142,15 +127,9 @@ class TestGaussianMixtureConverter(unittest.TestCase):
             model,
             model_onnx,
             basename="GaussianMixtureC2",
-            intermediate_steps=True,
-            # Operator gemm is not implemented in onnxruntime
-            allow_failure="StrictVersion(onnx.__version__)"
-                          " < StrictVersion('1.2')",
-        )
+            intermediate_steps=True)
         self._test_score(model, X, TARGET_OPSET)
 
-    @unittest.skipIf(not onnx_built_with_ml(),
-                     reason="Requires ONNX-ML extension.")
     @ignore_warnings(category=UserWarning)
     def test_gaussian_mixture_full(self):
         data = load_iris()
@@ -166,15 +145,9 @@ class TestGaussianMixtureConverter(unittest.TestCase):
             model,
             model_onnx,
             basename="GaussianMixtureC2Full",
-            intermediate_steps=True,
-            # Operator gemm is not implemented in onnxruntime
-            allow_failure="StrictVersion(onnx.__version__)"
-                          " < StrictVersion('1.2')",
-        )
+            intermediate_steps=True)
         self._test_score(model, X, TARGET_OPSET)
 
-    @unittest.skipIf(not onnx_built_with_ml(),
-                     reason="Requires ONNX-ML extension.")
     @ignore_warnings(category=UserWarning)
     def test_gaussian_mixture_tied(self):
         data = load_iris()
@@ -190,15 +163,9 @@ class TestGaussianMixtureConverter(unittest.TestCase):
             model,
             model_onnx,
             basename="GaussianMixtureC2Tied",
-            intermediate_steps=True,
-            # Operator gemm is not implemented in onnxruntime
-            allow_failure="StrictVersion(onnx.__version__)"
-                          " < StrictVersion('1.2')",
-        )
+            intermediate_steps=True)
         self._test_score(model, X, TARGET_OPSET)
 
-    @unittest.skipIf(not onnx_built_with_ml(),
-                     reason="Requires ONNX-ML extension.")
     @ignore_warnings(category=UserWarning)
     def test_gaussian_mixture_diag(self):
         data = load_iris()
@@ -215,15 +182,9 @@ class TestGaussianMixtureConverter(unittest.TestCase):
             model,
             model_onnx,
             basename="GaussianMixtureC2Diag",
-            intermediate_steps=True,
-            # Operator gemm is not implemented in onnxruntime
-            allow_failure="StrictVersion(onnx.__version__)"
-                          " < StrictVersion('1.2')",
-        )
+            intermediate_steps=True)
         self._test_score(model, X, TARGET_OPSET, decimal=4)
 
-    @unittest.skipIf(not onnx_built_with_ml(),
-                     reason="Requires ONNX-ML extension.")
     @ignore_warnings(category=UserWarning)
     def test_gaussian_mixture_spherical(self):
         data = load_iris()
@@ -238,14 +199,9 @@ class TestGaussianMixtureConverter(unittest.TestCase):
             X.astype(np.float32)[40:60],
             model, model_onnx,
             basename="GaussianMixtureC2Spherical",
-            intermediate_steps=True,
-            # Operator gemm is not implemented in onnxruntime
-            allow_failure="StrictVersion(onnx.__version__)"
-                          " < StrictVersion('1.2')")
+            intermediate_steps=True)
         self._test_score(model, X, TARGET_OPSET, decimal=4)
 
-    @unittest.skipIf(not onnx_built_with_ml(),
-                     reason="Requires ONNX-ML extension.")
     @ignore_warnings(category=UserWarning)
     def test_gaussian_mixture_full_black_op(self):
         data = load_iris()
@@ -266,15 +222,9 @@ class TestGaussianMixtureConverter(unittest.TestCase):
             model,
             model_onnx,
             basename="GaussianMixtureC2FullBL",
-            intermediate_steps=True,
-            # Operator gemm is not implemented in onnxruntime
-            allow_failure="StrictVersion(onnx.__version__)"
-                          " < StrictVersion('1.2')",
-        )
+            intermediate_steps=True)
         self._test_score(model, X, TARGET_OPSET)
 
-    @unittest.skipIf(not onnx_built_with_ml(),
-                     reason="Requires ONNX-ML extension.")
     @unittest.skipIf(TARGET_OPSET < 11,
                      reason="OnnxEqual does not support float")
     @ignore_warnings(category=UserWarning)
@@ -297,15 +247,9 @@ class TestGaussianMixtureConverter(unittest.TestCase):
             X.astype(np.float32)[40:60],
             model, model_onnx,
             basename="GaussianMixtureC2FullBLNM",
-            intermediate_steps=True,
-            # Operator gemm is not implemented in onnxruntime
-            allow_failure="StrictVersion(onnx.__version__)"
-                          " < StrictVersion('1.2')",
-        )
+            intermediate_steps=True)
         self._test_score(model, X, TARGET_OPSET)
 
-    @unittest.skipIf(not onnx_built_with_ml(),
-                     reason="Requires ONNX-ML extension.")
     @unittest.skipIf(TARGET_OPSET < 11,
                      reason="OnnxEqual does not support float")
     @ignore_warnings(category=UserWarning)
