@@ -5,17 +5,25 @@ import unittest
 import inspect
 import warnings
 from io import StringIO
-from distutils.version import StrictVersion
+import packaging.version as pv
 import numpy as np
 import pandas as pd
 from numpy.testing import assert_almost_equal
+from sklearn.preprocessing import MinMaxScaler
+from sklearn.pipeline import make_pipeline
 from sklearn.datasets import load_iris, make_regression
 from sklearn.gaussian_process import GaussianProcessRegressor
 from sklearn.gaussian_process.kernels import (
     Sum, DotProduct, ExpSineSquared, RationalQuadratic,
-    RBF, ConstantKernel as C, PairwiseKernel
-)
+    RBF, ConstantKernel as C, PairwiseKernel)
 from sklearn.model_selection import train_test_split
+try:
+    # scikit-learn >= 0.22
+    from sklearn.utils._testing import ignore_warnings
+except ImportError:
+    # scikit-learn < 0.22
+    from sklearn.utils.testing import ignore_warnings
+from sklearn.exceptions import ConvergenceWarning
 from skl2onnx.common.data_types import FloatTensorType, DoubleTensorType
 from skl2onnx import to_onnx
 from skl2onnx.proto import get_latest_tested_opset_version
@@ -34,8 +42,8 @@ except ImportError:
 from onnxruntime import __version__ as ort_version
 from test_utils import dump_data_and_model, fit_regression_model, TARGET_OPSET
 
-
 _TARGET_OPSET_ = min(get_latest_tested_opset_version(), TARGET_OPSET)
+ort_version = ".".join(ort_version.split('.')[:2])
 
 
 Xtrain_ = pd.read_csv(StringIO("""
@@ -141,8 +149,9 @@ class TestSklearnGaussianProcessRegressor(unittest.TestCase):
                                 np.squeeze(got), decimal=decimal)
 
     @unittest.skipIf(
-        StrictVersion(ort_version) <= StrictVersion(THRESHOLD),
+        pv.Version(ort_version) <= pv.Version(THRESHOLD),
         reason="onnxruntime %s" % THRESHOLD)
+    @ignore_warnings(category=(DeprecationWarning, ConvergenceWarning))
     def test_kernel_constant1(self):
         ker = C(5.)
         onx = convert_kernel(ker, 'X', output_names=['Y'], dtype=np.float32,
@@ -157,8 +166,9 @@ class TestSklearnGaussianProcessRegressor(unittest.TestCase):
         assert_almost_equal(m1, m2, decimal=5)
 
     @unittest.skipIf(
-        StrictVersion(ort_version) <= StrictVersion(THRESHOLD),
+        pv.Version(ort_version) <= pv.Version(THRESHOLD),
         reason="onnxruntime %s" % THRESHOLD)
+    @ignore_warnings(category=(DeprecationWarning, ConvergenceWarning))
     def test_kernel_cosine_float(self):
         ker = PairwiseKernel(metric='cosine')
 
@@ -194,8 +204,9 @@ class TestSklearnGaussianProcessRegressor(unittest.TestCase):
         assert_almost_equal(m1, m2, decimal=5)
 
     @unittest.skipIf(
-        StrictVersion(ort_version) <= StrictVersion(THRESHOLD),
+        pv.Version(ort_version) <= pv.Version(THRESHOLD),
         reason="onnxruntime %s" % THRESHOLD)
+    @ignore_warnings(category=(DeprecationWarning, ConvergenceWarning))
     def test_kernel_cosine_double(self):
         ker = PairwiseKernel(metric='cosine')
         onx = convert_kernel(ker, 'X', output_names=['Y'], dtype=np.float64,
@@ -219,8 +230,9 @@ class TestSklearnGaussianProcessRegressor(unittest.TestCase):
         assert_almost_equal(m1, m2, decimal=5)
 
     @unittest.skipIf(
-        StrictVersion(ort_version) <= StrictVersion(THRESHOLD),
+        pv.Version(ort_version) <= pv.Version(THRESHOLD),
         reason="onnxruntime %s" % THRESHOLD)
+    @ignore_warnings(category=(DeprecationWarning, ConvergenceWarning))
     def test_kernel_rbf1(self):
         ker = RBF(length_scale=1, length_scale_bounds=(1e-3, 1e3))
         onx = convert_kernel(ker, 'X', output_names=['Y'], dtype=np.float32,
@@ -234,8 +246,9 @@ class TestSklearnGaussianProcessRegressor(unittest.TestCase):
         assert_almost_equal(m1, m2, decimal=5)
 
     @unittest.skipIf(
-        StrictVersion(ort_version) <= StrictVersion(THRESHOLD),
+        pv.Version(ort_version) <= pv.Version(THRESHOLD),
         reason="onnxruntime %s" % THRESHOLD)
+    @ignore_warnings(category=(DeprecationWarning, ConvergenceWarning))
     def test_kernel_rbf10(self):
         ker = RBF(length_scale=10, length_scale_bounds=(1e-3, 1e3))
         onx = convert_kernel(ker, 'X', output_names=['Y'], dtype=np.float32,
@@ -249,8 +262,9 @@ class TestSklearnGaussianProcessRegressor(unittest.TestCase):
         assert_almost_equal(m1, m2, decimal=5)
 
     @unittest.skipIf(
-        StrictVersion(ort_version) <= StrictVersion(THRESHOLD),
+        pv.Version(ort_version) <= pv.Version(THRESHOLD),
         reason="onnxruntime %s" % THRESHOLD)
+    @ignore_warnings(category=(DeprecationWarning, ConvergenceWarning))
     def test_kernel_rbf2(self):
         ker = RBF(length_scale=1, length_scale_bounds="fixed")
         onx = convert_kernel(ker, 'X', output_names=['Y'], dtype=np.float32,
@@ -264,8 +278,9 @@ class TestSklearnGaussianProcessRegressor(unittest.TestCase):
         assert_almost_equal(m1, m2, decimal=5)
 
     @unittest.skipIf(
-        StrictVersion(ort_version) <= StrictVersion(THRESHOLD),
+        pv.Version(ort_version) <= pv.Version(THRESHOLD),
         reason="onnxruntime %s" % THRESHOLD)
+    @ignore_warnings(category=(DeprecationWarning, ConvergenceWarning))
     def test_kernel_rbf_mul(self):
         ker = (C(1.0, constant_value_bounds="fixed") *
                RBF(1.0, length_scale_bounds="fixed"))
@@ -281,8 +296,9 @@ class TestSklearnGaussianProcessRegressor(unittest.TestCase):
         assert_almost_equal(m1, m2, decimal=5)
 
     @unittest.skipIf(
-        StrictVersion(ort_version) <= StrictVersion(THRESHOLD),
+        pv.Version(ort_version) <= pv.Version(THRESHOLD),
         reason="onnxruntime %s" % THRESHOLD)
+    @ignore_warnings(category=(DeprecationWarning, ConvergenceWarning))
     def test_kernel_ker1_def(self):
         ker = (C(1.0, (1e-3, 1e3)) *
                RBF(length_scale=10, length_scale_bounds=(1e-3, 1e3)))
@@ -298,8 +314,9 @@ class TestSklearnGaussianProcessRegressor(unittest.TestCase):
         assert_almost_equal(m1, m2, decimal=5)
 
     @unittest.skipIf(
-        StrictVersion(ort_version) <= StrictVersion(THRESHOLD),
+        pv.Version(ort_version) <= pv.Version(THRESHOLD),
         reason="onnxruntime %s" % THRESHOLD)
+    @ignore_warnings(category=(DeprecationWarning, ConvergenceWarning))
     def test_kernel_ker12_def(self):
         ker = (Sum(C(0.1, (1e-3, 1e3)), C(0.1, (1e-3, 1e3)) *
                RBF(length_scale=1, length_scale_bounds=(1e-3, 1e3))))
@@ -315,8 +332,9 @@ class TestSklearnGaussianProcessRegressor(unittest.TestCase):
         assert_almost_equal(m1, m2, decimal=5)
 
     @unittest.skipIf(
-        StrictVersion(ort_version) <= StrictVersion(THRESHOLD),
+        pv.Version(ort_version) <= pv.Version(THRESHOLD),
         reason="onnxruntime %s" % THRESHOLD)
+    @ignore_warnings(category=(DeprecationWarning, ConvergenceWarning))
     def test_kernel_ker2_def(self):
         ker = Sum(
             C(0.1, (1e-3, 1e3)) * RBF(length_scale=10,
@@ -336,8 +354,9 @@ class TestSklearnGaussianProcessRegressor(unittest.TestCase):
         assert_almost_equal(m1, m2, decimal=0)
 
     @unittest.skipIf(
-        StrictVersion(ort_version) <= StrictVersion(THRESHOLD),
+        pv.Version(ort_version) <= pv.Version(THRESHOLD),
         reason="onnxruntime %s" % THRESHOLD)
+    @ignore_warnings(category=(DeprecationWarning, ConvergenceWarning))
     def test_kernel_ker2_dotproduct(self):
         ker = DotProduct(sigma_0=2.)
         onx = convert_kernel(ker, 'X', output_names=['Y'], dtype=np.float32,
@@ -360,8 +379,9 @@ class TestSklearnGaussianProcessRegressor(unittest.TestCase):
         assert_almost_equal(m1, m2, decimal=2)
 
     @unittest.skipIf(
-        StrictVersion(ort_version) <= StrictVersion(THRESHOLD),
+        pv.Version(ort_version) <= pv.Version(THRESHOLD),
         reason="onnxruntime %s" % THRESHOLD)
+    @ignore_warnings(category=(DeprecationWarning, ConvergenceWarning))
     def test_kernel_ker2_exp_sine_squared(self):
         ker = ExpSineSquared()
         onx = convert_kernel(ker, 'X', output_names=['Y'], dtype=np.float32,
@@ -388,8 +408,9 @@ class TestSklearnGaussianProcessRegressor(unittest.TestCase):
         assert_almost_equal(m1, m2, decimal=4)
 
     @unittest.skipIf(
-        StrictVersion(ort_version) <= StrictVersion(THRESHOLD),
+        pv.Version(ort_version) <= pv.Version(THRESHOLD),
         reason="onnxruntime %s" % THRESHOLD)
+    @ignore_warnings(category=(DeprecationWarning, ConvergenceWarning))
     def test_kernel_exp_sine_squared_diag(self):
         ker = ExpSineSquared()
         onx = convert_kernel_diag(
@@ -405,8 +426,9 @@ class TestSklearnGaussianProcessRegressor(unittest.TestCase):
         assert_almost_equal(m1, m2, decimal=4)
 
     @unittest.skipIf(
-        StrictVersion(ort_version) <= StrictVersion(THRESHOLD),
+        pv.Version(ort_version) <= pv.Version(THRESHOLD),
         reason="onnxruntime %s" % THRESHOLD)
+    @ignore_warnings(category=(DeprecationWarning, ConvergenceWarning))
     def test_kernel_rational_quadratic_diag(self):
         ker = RationalQuadratic()
         onx = convert_kernel_diag(
@@ -422,8 +444,9 @@ class TestSklearnGaussianProcessRegressor(unittest.TestCase):
         assert_almost_equal(m1, m2, decimal=4)
 
     @unittest.skipIf(
-        StrictVersion(ort_version) <= StrictVersion(THRESHOLD),
+        pv.Version(ort_version) <= pv.Version(THRESHOLD),
         reason="onnxruntime %s" % THRESHOLD)
+    @ignore_warnings(category=(DeprecationWarning, ConvergenceWarning))
     def test_kernel_dot_product_diag(self):
         ker = DotProduct()
         onx = convert_kernel_diag(
@@ -439,8 +462,9 @@ class TestSklearnGaussianProcessRegressor(unittest.TestCase):
         assert_almost_equal(m1 / 1000, m2 / 1000, decimal=5)
 
     @unittest.skipIf(
-        StrictVersion(ort_version) <= StrictVersion(THRESHOLD),
+        pv.Version(ort_version) <= pv.Version(THRESHOLD),
         reason="onnxruntime %s" % THRESHOLD)
+    @ignore_warnings(category=(DeprecationWarning, ConvergenceWarning))
     def test_kernel_dot_product(self):
         ker = DotProduct()
         onx = convert_kernel(ker, 'X', output_names=['Y'], dtype=np.float32,
@@ -467,8 +491,9 @@ class TestSklearnGaussianProcessRegressor(unittest.TestCase):
         assert_almost_equal(m1 / 1000, m2 / 1000, decimal=5)
 
     @unittest.skipIf(
-        StrictVersion(ort_version) <= StrictVersion(THRESHOLD),
+        pv.Version(ort_version) <= pv.Version(THRESHOLD),
         reason="onnxruntime %s" % THRESHOLD)
+    @ignore_warnings(category=(DeprecationWarning, ConvergenceWarning))
     def test_kernel_rational_quadratic(self):
         ker = RationalQuadratic()
         onx = convert_kernel(ker, 'X', output_names=['Y'], dtype=np.float32,
@@ -494,8 +519,9 @@ class TestSklearnGaussianProcessRegressor(unittest.TestCase):
         assert_almost_equal(m1, m2, decimal=3)
 
     @unittest.skipIf(
-        StrictVersion(ort_version) <= StrictVersion(THRESHOLD),
+        pv.Version(ort_version) <= pv.Version(THRESHOLD),
         reason="onnxruntime %s" % THRESHOLD)
+    @ignore_warnings(category=(DeprecationWarning, ConvergenceWarning))
     def test_gpr_rbf_unfitted(self):
 
         se = (C(1.0, (1e-3, 1e3)) *
@@ -549,11 +575,12 @@ class TestSklearnGaussianProcessRegressor(unittest.TestCase):
             GaussianProcessRegressor])
 
     @unittest.skipIf(
-        StrictVersion(ort_version) < StrictVersion("1.6.0"),
+        pv.Version(ort_version) < pv.Version("1.6.0"),
         reason="shape_inference fails")
     @unittest.skipIf(
-        StrictVersion(ort_version) <= StrictVersion(THRESHOLD),
+        pv.Version(ort_version) <= pv.Version(THRESHOLD),
         reason="onnxruntime %s" % THRESHOLD)
+    @ignore_warnings(category=(DeprecationWarning, ConvergenceWarning))
     def test_gpr_rbf_fitted_true(self):
 
         gp = GaussianProcessRegressor(alpha=1e-5,
@@ -571,11 +598,12 @@ class TestSklearnGaussianProcessRegressor(unittest.TestCase):
                             basename="SklearnGaussianProcessRBFTDouble")
 
     @unittest.skipIf(
-        StrictVersion(ort_version) < StrictVersion("1.6.0"),
+        pv.Version(ort_version) < pv.Version("1.6.0"),
         reason="shape_inference fails")
     @unittest.skipIf(
-        StrictVersion(ort_version) <= StrictVersion(THRESHOLD),
+        pv.Version(ort_version) <= pv.Version(THRESHOLD),
         reason="onnxruntime %s" % THRESHOLD)
+    @ignore_warnings(category=(DeprecationWarning, ConvergenceWarning))
     def test_gpr_cosine_fitted_true_float(self):
         gp = GaussianProcessRegressor(alpha=1e-5,
                                       n_restarts_optimizer=25,
@@ -594,11 +622,12 @@ class TestSklearnGaussianProcessRegressor(unittest.TestCase):
                             basename="SklearnGaussianProcessCosineFloat-Dec2")
 
     @unittest.skipIf(
-        StrictVersion(ort_version) < StrictVersion("1.6.0"),
+        pv.Version(ort_version) < pv.Version("1.6.0"),
         reason="shape_inference fails")
     @unittest.skipIf(
-        StrictVersion(ort_version) <= StrictVersion(THRESHOLD),
+        pv.Version(ort_version) <= pv.Version(THRESHOLD),
         reason="onnxruntime %s" % THRESHOLD)
+    @ignore_warnings(category=(DeprecationWarning, ConvergenceWarning))
     def test_gpr_cosine_fitted_true_double(self):
         gp = GaussianProcessRegressor(alpha=1e-5,
                                       n_restarts_optimizer=25,
@@ -617,8 +646,9 @@ class TestSklearnGaussianProcessRegressor(unittest.TestCase):
                             basename="SklearnGaussianProcessCosineDouble")
 
     @unittest.skipIf(
-        StrictVersion(ort_version) <= StrictVersion(THRESHOLD),
+        pv.Version(ort_version) <= pv.Version(THRESHOLD),
         reason="onnxruntime %s" % THRESHOLD)
+    @ignore_warnings(category=(DeprecationWarning, ConvergenceWarning))
     def test_gpr_rbf_fitted_false(self):
 
         gp = GaussianProcessRegressor(alpha=1e-5,
@@ -636,8 +666,9 @@ class TestSklearnGaussianProcessRegressor(unittest.TestCase):
                             basename="SklearnGaussianProcessRBF-Dec4")
 
     @unittest.skipIf(
-        StrictVersion(ort_version) <= StrictVersion(THRESHOLD),
+        pv.Version(ort_version) <= pv.Version(THRESHOLD),
         reason="onnxruntime %s" % THRESHOLD)
+    @ignore_warnings(category=(DeprecationWarning, ConvergenceWarning))
     def test_gpr_rbf_fitted_return_std_true(self):
         gp = GaussianProcessRegressor(alpha=1e-5,
                                       n_restarts_optimizer=25,
@@ -667,10 +698,11 @@ class TestSklearnGaussianProcessRegressor(unittest.TestCase):
                             disable_optimisation=True)
 
     @unittest.skipIf(
-        StrictVersion(ort_version) <= StrictVersion(THRESHOLD),
+        pv.Version(ort_version) <= pv.Version(THRESHOLD),
         reason="onnxruntime %s" % THRESHOLD)
     @unittest.skipIf(
         TARGET_OPSET >= 12, reason="TARGET_OPSET < 12")
+    @ignore_warnings(category=(DeprecationWarning, ConvergenceWarning))
     def test_gpr_rbf_fitted_return_std_exp_sine_squared_true(self):
         state = np.random.RandomState(0)
         X = 15 * state.rand(100, 2)
@@ -706,8 +738,9 @@ class TestSklearnGaussianProcessRegressor(unittest.TestCase):
             decimal=4, disable_optimisation=True)
 
     @unittest.skipIf(
-        StrictVersion(ort_version) <= StrictVersion(THRESHOLD),
+        pv.Version(ort_version) <= pv.Version(THRESHOLD),
         reason="onnxruntime %s" % THRESHOLD)
+    @ignore_warnings(category=(DeprecationWarning, ConvergenceWarning))
     def test_gpr_rbf_fitted_return_std_exp_sine_squared_false(self):
         X = 15 * np.random.rand(100, 2)
         y = np.sin(X[:, 0] - X[:, 1]).ravel()
@@ -740,8 +773,9 @@ class TestSklearnGaussianProcessRegressor(unittest.TestCase):
             decimal=3)
 
     @unittest.skipIf(
-        StrictVersion(ort_version) <= StrictVersion(THRESHOLD),
+        pv.Version(ort_version) <= pv.Version(THRESHOLD),
         reason="onnxruntime %s" % THRESHOLD)
+    @ignore_warnings(category=(DeprecationWarning, ConvergenceWarning))
     def test_gpr_rbf_fitted_return_std_exp_sine_squared_double_true(self):
 
         gp = GaussianProcessRegressor(kernel=ExpSineSquared(),
@@ -775,10 +809,11 @@ class TestSklearnGaussianProcessRegressor(unittest.TestCase):
             decimal=3, disable_optimisation=True)
 
     @unittest.skipIf(
-        StrictVersion(ort_version) <= StrictVersion(THRESHOLD),
+        pv.Version(ort_version) <= pv.Version(THRESHOLD),
         reason="onnxruntime %s" % THRESHOLD)
     @unittest.skipIf(
         TARGET_OPSET >= 12, reason="TARGET_OPSET < 12")
+    @ignore_warnings(category=(DeprecationWarning, ConvergenceWarning))
     def test_gpr_rbf_fitted_return_std_dot_product_true(self):
         X = 15 * np.random.rand(100, 2)
         y = np.sin(X[:, 0] - X[:, 1]).ravel()
@@ -813,10 +848,11 @@ class TestSklearnGaussianProcessRegressor(unittest.TestCase):
             decimal=3, disable_optimisation=True)
 
     @unittest.skipIf(
-        StrictVersion(ort_version) <= StrictVersion(THRESHOLD),
+        pv.Version(ort_version) <= pv.Version(THRESHOLD),
         reason="onnxruntime %s" % THRESHOLD)
     @unittest.skipIf(
         TARGET_OPSET >= 12, reason="TARGET_OPSET < 12")
+    @ignore_warnings(category=(DeprecationWarning, ConvergenceWarning))
     def test_gpr_rbf_fitted_return_std_rational_quadratic_true(self):
 
         X, y = make_regression(n_features=2, n_informative=2, random_state=2)
@@ -848,8 +884,9 @@ class TestSklearnGaussianProcessRegressor(unittest.TestCase):
             disable_optimisation=True)
 
     @unittest.skipIf(
-        StrictVersion(ort_version) <= StrictVersion(THRESHOLD),
+        pv.Version(ort_version) <= pv.Version(THRESHOLD),
         reason="onnxruntime %s" % THRESHOLD)
+    @ignore_warnings(category=(DeprecationWarning, ConvergenceWarning))
     def test_gpr_fitted_shapes(self):
         data = load_iris()
         X = data.data.astype(np.float32)
@@ -865,8 +902,9 @@ class TestSklearnGaussianProcessRegressor(unittest.TestCase):
         self.check_outputs(gp, model_onnx, X_test, {}, skip_if_float32=True)
 
     @unittest.skipIf(
-        StrictVersion(ort_version) <= StrictVersion(THRESHOLD),
+        pv.Version(ort_version) <= pv.Version(THRESHOLD),
         reason="onnxruntime %s" % THRESHOLD)
+    @ignore_warnings(category=(DeprecationWarning, ConvergenceWarning))
     def test_gpr_fitted_partial_float64(self):
         data = load_iris()
         X = data.data
@@ -891,8 +929,9 @@ class TestSklearnGaussianProcessRegressor(unittest.TestCase):
         self.check_outputs(gp, model_onnx, X_test, {})
 
     @unittest.skipIf(
-        StrictVersion(ort_version) <= StrictVersion(THRESHOLD2),
+        pv.Version(ort_version) <= pv.Version(THRESHOLD2),
         reason="onnxruntime %s" % THRESHOLD)
+    @ignore_warnings(category=(DeprecationWarning, ConvergenceWarning))
     def test_gpr_fitted_partial_float64_operator_cdist_rbf(self):
         data = load_iris()
         X = data.data
@@ -933,8 +972,9 @@ class TestSklearnGaussianProcessRegressor(unittest.TestCase):
         self.check_outputs(gp, model_onnx, X_test, {})
 
     @unittest.skipIf(
-        StrictVersion(ort_version) <= StrictVersion(THRESHOLD2),
+        pv.Version(ort_version) <= pv.Version(THRESHOLD2),
         reason="onnxruntime %s" % THRESHOLD)
+    @ignore_warnings(category=(DeprecationWarning, ConvergenceWarning))
     def test_gpr_fitted_partial_float64_operator_cdist_sine(self):
         data = load_iris()
         X = data.data[:, :2]
@@ -975,8 +1015,9 @@ class TestSklearnGaussianProcessRegressor(unittest.TestCase):
         self.check_outputs(gp, model_onnx, X_test, {})
 
     @unittest.skipIf(
-        StrictVersion(ort_version) <= StrictVersion(THRESHOLD2),
+        pv.Version(ort_version) <= pv.Version(THRESHOLD2),
         reason="onnxruntime %s" % THRESHOLD)
+    @ignore_warnings(category=(DeprecationWarning, ConvergenceWarning))
     def test_gpr_fitted_partial_float64_operator_cdist_quad(self):
         data = load_iris()
         X = data.data
@@ -1016,6 +1057,43 @@ class TestSklearnGaussianProcessRegressor(unittest.TestCase):
         self.assertTrue(model_onnx is not None)
         self.check_outputs(gp, model_onnx, X_test, {})
 
+    def test_issue_789(self):
+        n_samples, n_features = 10000, 10
+        X, y = make_regression(n_samples, n_features)
+        tx1, vx1, ty1, vy1 = train_test_split(X, y)
+        model = GaussianProcessRegressor()
+        pipe = make_pipeline(MinMaxScaler(feature_range=(-1, 1)), model)
+        pipe.fit(tx1, ty1)
+        initial_type = [('data_in', DoubleTensorType([None, X.shape[1]]))]
+        onx = to_onnx(pipe, initial_types=initial_type,
+                      target_opset=_TARGET_OPSET_)
+        sess = InferenceSession(onx.SerializeToString())
+        pred = sess.run(None, {'data_in': vx1.astype(np.float64)})
+        assert_almost_equal(pipe.predict(vx1.astype(np.float64)).ravel(),
+                            pred[0].ravel())
+
+    def test_issue_789_cdist(self):
+        n_samples, n_features = 10000, 10
+        X, y = make_regression(n_samples, n_features)
+        tx1, vx1, ty1, vy1 = train_test_split(X, y)
+        model = GaussianProcessRegressor()
+        pipe = make_pipeline(MinMaxScaler(feature_range=(-1, 1)), model)
+        pipe.fit(tx1, ty1)
+        initial_type = [('data_in', DoubleTensorType([None, X.shape[1]]))]
+        onx = to_onnx(pipe, initial_types=initial_type,
+                      target_opset=_TARGET_OPSET_,
+                      options={GaussianProcessRegressor: {'optim': 'cdist'}})
+        self.assertIn('op_type: "CDist"', str(onx))
+        sess = InferenceSession(onx.SerializeToString())
+        pred = sess.run(None, {'data_in': vx1.astype(np.float64)})
+        assert_almost_equal(pipe.predict(vx1.astype(np.float64)).ravel(),
+                            pred[0].ravel())
+
 
 if __name__ == "__main__":
+    # import logging
+    # log = logging.getLogger('skl2onnx')
+    # log.setLevel(logging.DEBUG)
+    # logging.basicConfig(level=logging.DEBUG)
+    # TestSklearnGaussianProcessRegressor().test_issue_789()
     unittest.main()
