@@ -4,7 +4,7 @@
 Test scikit-learn's IsolationForest.
 """
 import unittest
-from distutils.version import StrictVersion
+import packaging.version as pv
 import numpy as np
 from numpy.testing import assert_almost_equal
 from onnxruntime import InferenceSession
@@ -14,7 +14,7 @@ try:
 except ImportError:
     IsolationForest = None
 from skl2onnx import to_onnx
-from test_utils import dump_data_and_model, TARGET_OPSET
+from test_utils import dump_data_and_model, TARGET_OPSET, TARGET_OPSET_ML
 try:
     from onnxruntime.capi.onnxruntime_pybind11_state import NotImplemented
 except ImportError:
@@ -27,28 +27,33 @@ sklv2 = '.'.join(sklv.split('.')[:2])
 class TestSklearnIsolationForest(unittest.TestCase):
 
     @unittest.skipIf(IsolationForest is None, reason="old scikit-learn")
-    @unittest.skipIf(StrictVersion(sklv2) < StrictVersion('0.22.0'),
+    @unittest.skipIf(pv.Version(sklv2) < pv.Version('0.22.0'),
                      reason="tree structure is different.")
+    @unittest.skipIf(TARGET_OPSET < 12, reason="not available")
     def test_isolation_forest(self):
         isol = IsolationForest(n_estimators=3, random_state=0)
         data = np.array([[-1.1, -1.2], [0.3, 0.2],
                          [0.5, 0.4], [100., 99.]], dtype=np.float32)
         model = isol.fit(data)
-        model_onnx = to_onnx(model, data, target_opset=TARGET_OPSET)
+        model_onnx = to_onnx(
+            model, data,
+            target_opset={'': TARGET_OPSET, 'ai.onnx.ml': TARGET_OPSET_ML})
         self.assertIsNotNone(model_onnx)
         dump_data_and_model(data, model, model_onnx,
                             basename="IsolationForest")
 
     @unittest.skipIf(IsolationForest is None, reason="old scikit-learn")
-    @unittest.skipIf(StrictVersion(sklv2) < StrictVersion('0.22.0'),
+    @unittest.skipIf(pv.Version(sklv2) < pv.Version('0.22.0'),
                      reason="tree structure is different.")
+    @unittest.skipIf(TARGET_OPSET < 12, reason="not available")
     def test_isolation_forest_score_samples(self):
         isol = IsolationForest(n_estimators=3, random_state=0)
         data = np.array([[-1.1, -1.2], [0.3, 0.2],
                          [0.5, 0.4], [100., 99.]], dtype=np.float32)
         model = isol.fit(data)
-        model_onnx = to_onnx(model, data, target_opset=TARGET_OPSET,
-                             options={'score_samples': True})
+        model_onnx = to_onnx(
+            model, data, options={'score_samples': True},
+            target_opset={'': TARGET_OPSET, 'ai.onnx.ml': TARGET_OPSET_ML})
         sess = InferenceSession(model_onnx.SerializeToString())
         names = [o.name for o in sess.get_outputs()]
         self.assertEqual(names, ['label', 'scores', 'score_samples'])
@@ -62,8 +67,9 @@ class TestSklearnIsolationForest(unittest.TestCase):
         assert_almost_equal(expected_score, got[2].ravel())
 
     @unittest.skipIf(IsolationForest is None, reason="old scikit-learn")
-    @unittest.skipIf(StrictVersion(sklv2) < StrictVersion('0.22.0'),
+    @unittest.skipIf(pv.Version(sklv2) < pv.Version('0.22.0'),
                      reason="tree structure is different.")
+    @unittest.skipIf(TARGET_OPSET < 12, reason="not available")
     def test_isolation_forest_op1(self):
         isol = IsolationForest(n_estimators=3, random_state=0)
         data = np.array([[-1.1, -1.2], [0.3, 0.2],
@@ -74,8 +80,9 @@ class TestSklearnIsolationForest(unittest.TestCase):
                     target_opset={'': TARGET_OPSET, 'ai.onnx.ml': 1})
 
     @unittest.skipIf(IsolationForest is None, reason="old scikit-learn")
-    @unittest.skipIf(StrictVersion(sklv2) < StrictVersion('0.22.0'),
+    @unittest.skipIf(pv.Version(sklv2) < pv.Version('0.22.0'),
                      reason="tree structure is different.")
+    @unittest.skipIf(TARGET_OPSET < 12, reason="not available")
     def test_isolation_forest_rnd(self):
         isol = IsolationForest(n_estimators=2, random_state=0)
         rs = np.random.RandomState(0)
@@ -83,7 +90,9 @@ class TestSklearnIsolationForest(unittest.TestCase):
         data[-1, 2:] = 99.
         data[-2, :2] = -99.
         model = isol.fit(data)
-        model_onnx = to_onnx(model, data, target_opset=TARGET_OPSET)
+        model_onnx = to_onnx(
+            model, data,
+            target_opset={'': TARGET_OPSET, 'ai.onnx.ml': TARGET_OPSET_ML})
         self.assertIsNotNone(model_onnx)
         dump_data_and_model(data, model, model_onnx,
                             basename="IsolationForestRnd")
