@@ -2,15 +2,17 @@
 
 import unittest
 import urllib.error as url_error
-from distutils.version import StrictVersion
+import packaging.version as pv
 from io import StringIO
 import warnings
 import numpy
 from numpy.testing import assert_almost_equal
 import pandas
-from sklearn import __version__ as sklearn_version
+from sklearn import __version__ as skl_version
 from sklearn import datasets
 from sklearn.calibration import CalibratedClassifierCV
+from sklearn.base import TransformerMixin, BaseEstimator
+from sklearn.tree import DecisionTreeClassifier
 
 try:
     # scikit-learn >= 0.22
@@ -20,9 +22,13 @@ except ImportError:
     from sklearn.utils.testing import ignore_warnings
 try:
     from sklearn.compose import ColumnTransformer
+    from sklearn.compose import (
+        make_column_transformer, make_column_selector)
 except ImportError:
     # not available in 0.19
     ColumnTransformer = None
+    make_column_selector = None
+    make_column_transformer = None
 from sklearn.decomposition import PCA, TruncatedSVD
 
 try:
@@ -46,16 +52,18 @@ from skl2onnx.common.data_types import (
     StringTensorType,
 )
 from sklearn.multioutput import MultiOutputClassifier
-from skl2onnx.common.data_types import onnx_built_with_ml
 from test_utils import (
     dump_data_and_model, fit_classification_model, TARGET_OPSET)
 from onnxruntime import __version__ as ort_version, InferenceSession
 
 
+# pv.Version does not work with development versions
+ort_version = ".".join(ort_version.split('.')[:2])
+skl_version = ".".join(skl_version.split('.')[:2])
+
+
 def check_scikit_version():
-    # StrictVersion does not work with development versions
-    vers = '.'.join(sklearn_version.split('.')[:2])
-    return StrictVersion(vers) >= StrictVersion("0.21.0")
+    return pv.Version(skl_version) >= pv.Version("0.22")
 
 
 class PipeConcatenateInput:
@@ -123,7 +131,7 @@ class TestSklearnPipeline(unittest.TestCase):
             model_onnx, basename="SklearnPipelineScaler11")
 
     @unittest.skipIf(
-        StrictVersion(ort_version) <= StrictVersion('0.4.0'),
+        pv.Version(ort_version) <= pv.Version('0.4.0'),
         reason="onnxruntime too old")
     @ignore_warnings(category=FutureWarning)
     def test_combine_inputs_union_in_pipeline(self):
@@ -164,7 +172,7 @@ class TestSklearnPipeline(unittest.TestCase):
             model_onnx, basename="SklearnPipelineScaler11Union")
 
     @unittest.skipIf(
-        StrictVersion(ort_version) <= StrictVersion('0.4.0'),
+        pv.Version(ort_version) <= pv.Version('0.4.0'),
         reason="onnxruntime too old")
     @ignore_warnings(category=FutureWarning)
     def test_combine_inputs_floats_ints(self):
@@ -194,11 +202,8 @@ class TestSklearnPipeline(unittest.TestCase):
 
     @unittest.skipIf(
         ColumnTransformer is None,
-        reason="ColumnTransformer not available in 0.19",
-    )
-    @unittest.skipIf(not onnx_built_with_ml(),
-                     reason="Requires ONNX-ML extension.")
-    @unittest.skipIf(StrictVersion(ort_version) <= StrictVersion("0.4.0"),
+        reason="ColumnTransformer not available in 0.19")
+    @unittest.skipIf(pv.Version(ort_version) <= pv.Version("0.4.0"),
                      reason="issues with shapes")
     @ignore_warnings(category=(RuntimeWarning, FutureWarning))
     def test_pipeline_column_transformer(self):
@@ -275,8 +280,6 @@ class TestSklearnPipeline(unittest.TestCase):
     @unittest.skipIf(
         ColumnTransformer is None,
         reason="ColumnTransformer not available in 0.19")
-    @unittest.skipIf(not onnx_built_with_ml(),
-                     reason="Requires ONNX-ML extension.")
     @unittest.skipIf(
         not check_scikit_version(),
         reason="Scikit 0.20 causes some mismatches")
@@ -403,8 +406,6 @@ class TestSklearnPipeline(unittest.TestCase):
     @unittest.skipIf(
         ColumnTransformer is None,
         reason="ColumnTransformer not available in 0.19")
-    @unittest.skipIf(not onnx_built_with_ml(),
-                     reason="Requires ONNX-ML extension.")
     @ignore_warnings(category=FutureWarning)
     def test_column_transformer_weights(self):
         model, X = fit_classification_model(
@@ -425,8 +426,6 @@ class TestSklearnPipeline(unittest.TestCase):
     @unittest.skipIf(
         ColumnTransformer is None,
         reason="ColumnTransformer not available in 0.19")
-    @unittest.skipIf(not onnx_built_with_ml(),
-                     reason="Requires ONNX-ML extension.")
     @ignore_warnings(category=FutureWarning)
     def test_column_transformer_drop(self):
         model, X = fit_classification_model(
@@ -447,8 +446,6 @@ class TestSklearnPipeline(unittest.TestCase):
     @unittest.skipIf(
         ColumnTransformer is None,
         reason="ColumnTransformer not available in 0.19")
-    @unittest.skipIf(not onnx_built_with_ml(),
-                     reason="Requires ONNX-ML extension.")
     @ignore_warnings(category=FutureWarning)
     def test_column_transformer_passthrough(self):
         model, X = fit_classification_model(
@@ -470,8 +467,6 @@ class TestSklearnPipeline(unittest.TestCase):
     @unittest.skipIf(
         ColumnTransformer is None,
         reason="ColumnTransformer not available in 0.19")
-    @unittest.skipIf(not onnx_built_with_ml(),
-                     reason="Requires ONNX-ML extension.")
     @ignore_warnings(category=FutureWarning)
     def test_column_transformer_passthrough_no_weights(self):
         model, X = fit_classification_model(
@@ -664,6 +659,9 @@ class TestSklearnPipeline(unittest.TestCase):
 
     @unittest.skipIf(TARGET_OPSET < 11,
                      reason="SequenceConstruct not available")
+    @unittest.skipIf(
+        not check_scikit_version(),
+        reason="Scikit 0.21 too old")
     @ignore_warnings(category=(FutureWarning, UserWarning))
     def test_pipeline_pipeline_rf(self):
         cat_feat = ['A', 'B']
@@ -699,7 +697,8 @@ class TestSklearnPipeline(unittest.TestCase):
                 ('A', StringTensorType([None, 1])),
                 ('B', StringTensorType([None, 1])),
                 ('TEXT', StringTensorType([None, 1]))],
-            target_opset=TARGET_OPSET)
+            target_opset=TARGET_OPSET,
+            options={MultiOutputClassifier: {'zipmap': False}})
         # with open("debug.onnx", "wb") as f:
         #     f.write(model_onnx.SerializeToString())
         sess = InferenceSession(model_onnx.SerializeToString())
@@ -712,6 +711,9 @@ class TestSklearnPipeline(unittest.TestCase):
 
     @unittest.skipIf(TARGET_OPSET < 11,
                      reason="SequenceConstruct not available")
+    @unittest.skipIf(
+        not check_scikit_version(),
+        reason="Scikit 0.21 too old")
     @ignore_warnings(category=(DeprecationWarning, FutureWarning, UserWarning))
     def test_issue_712_multio(self):
         dfx = pandas.DataFrame(
@@ -743,7 +745,8 @@ class TestSklearnPipeline(unittest.TestCase):
         inputs = {'CAT1': dfx['CAT1'].values.reshape((-1, 1)),
                   'CAT2': dfx['CAT2'].values.reshape((-1, 1)),
                   'TEXT': dfx['TEXT'].values.reshape((-1, 1))}
-        onx = to_onnx(rf_clf, dfx, target_opset=TARGET_OPSET)
+        onx = to_onnx(rf_clf, dfx, target_opset=TARGET_OPSET,
+                      options={MultiOutputClassifier: {'zipmap': False}})
         sess = InferenceSession(onx.SerializeToString())
 
         got = sess.run(None, inputs)
@@ -754,6 +757,9 @@ class TestSklearnPipeline(unittest.TestCase):
 
     @unittest.skipIf(TARGET_OPSET < 11,
                      reason="SequenceConstruct not available")
+    @unittest.skipIf(
+        not check_scikit_version(),
+        reason="Scikit 0.21 too old")
     @ignore_warnings(category=(DeprecationWarning, FutureWarning, UserWarning))
     def test_issue_712_svc_multio(self):
         for sub_model in [LinearSVC(), SVC()]:
@@ -799,7 +805,9 @@ class TestSklearnPipeline(unittest.TestCase):
                     inputs = {'CAT1': dfx['CAT1'].values.reshape((-1, 1)),
                               'CAT2': dfx['CAT2'].values.reshape((-1, 1)),
                               'TEXT': dfx['TEXT'].values.reshape((-1, 1))}
-                    onx = to_onnx(rf_clf, dfx, target_opset=TARGET_OPSET)
+                    onx = to_onnx(
+                        rf_clf, dfx, target_opset=TARGET_OPSET,
+                        options={MultiOutputClassifier: {'zipmap': False}})
                     sess = InferenceSession(onx.SerializeToString())
                     got = sess.run(None, inputs)
                     assert_almost_equal(expected_label, got[0])
@@ -813,6 +821,9 @@ class TestSklearnPipeline(unittest.TestCase):
 
     @unittest.skipIf(TARGET_OPSET < 11,
                      reason="SequenceConstruct not available")
+    @unittest.skipIf(
+        not check_scikit_version(),
+        reason="Scikit 0.21 too old")
     @ignore_warnings(category=(DeprecationWarning, FutureWarning, UserWarning))
     def test_issue_712_svc_binary0(self):
         for sub_model in [LinearSVC(), SVC()]:
@@ -864,6 +875,9 @@ class TestSklearnPipeline(unittest.TestCase):
 
     @unittest.skipIf(TARGET_OPSET < 11,
                      reason="SequenceConstruct not available")
+    @unittest.skipIf(
+        not check_scikit_version(),
+        reason="Scikit 0.21 too old")
     @ignore_warnings(category=(DeprecationWarning, FutureWarning, UserWarning))
     def test_issue_712_svc_multi(self):
         for sub_model in [SVC(), LinearSVC()]:
@@ -918,6 +932,82 @@ class TestSklearnPipeline(unittest.TestCase):
                     else:
                         assert_almost_equal(expected_proba, got[1], decimal=5)
 
+    @unittest.skipIf(TARGET_OPSET < 11,
+                     reason="SequenceConstruct not available")
+    @unittest.skipIf(
+        not check_scikit_version(),
+        reason="Scikit 0.21 too old")
+    @ignore_warnings(category=(FutureWarning, UserWarning))
+    def test_pipeline_make_column_selector(self):
+        X = pandas.DataFrame({
+            'city': ['London', 'London', 'Paris', 'Sallisaw'],
+            'rating': [5, 3, 4, 5]})
+        X['rating'] = X['rating'].astype(numpy.float32)
+        ct = make_column_transformer(
+            (StandardScaler(), make_column_selector(
+                dtype_include=numpy.number)),
+            (OneHotEncoder(), make_column_selector(
+                dtype_include=object)))
+        expected = ct.fit_transform(X)
+        onx = to_onnx(ct, X, target_opset=TARGET_OPSET)
+        sess = InferenceSession(onx.SerializeToString())
+        names = [i.name for i in sess.get_inputs()]
+        got = sess.run(None, {names[0]: X[names[0]].values.reshape((-1, 1)),
+                              names[1]: X[names[1]].values.reshape((-1, 1))})
+        assert_almost_equal(expected, got[0])
+
+    @unittest.skipIf(
+        not check_scikit_version(),
+        reason="Scikit 0.21 too old")
+    def test_feature_selector_no_converter(self):
+
+        class ColumnSelector(TransformerMixin, BaseEstimator):
+            def __init__(self, cols):
+                if not isinstance(cols, list):
+                    self.cols = [cols]
+                else:
+                    self.cols = cols
+
+            def fit(self, X, y):
+                return self
+
+            def transform(self, X):
+                X = X.copy()
+                return X[self.cols]
+
+        # Inspired from
+        # https://github.com/databricks/automl/blob/main/
+        # runtime/tests/automl_runtime/sklearn/column_selector_test.py
+        X_in = pandas.DataFrame(
+            numpy.array([[1, 2, 3], [4, 5, 6], [7, 8, 9]],
+                        dtype=numpy.float32),
+            columns=["a", "b", "c"])
+        y = pandas.DataFrame(numpy.array([[1], [0], [1]]),
+                             columns=["label"])
+        X_out_expected = numpy.array([1, 0, 1])
+
+        standardizer = StandardScaler()
+        selected_cols = ["a", "b"]
+        col_selector = ColumnSelector(selected_cols)
+        preprocessor = ColumnTransformer(
+            [("standardizer", standardizer, selected_cols)], remainder="drop")
+
+        model = Pipeline([
+            ("column_selector", col_selector),
+            ("preprocessor", preprocessor),
+            ("decision_tree", DecisionTreeClassifier())
+        ])
+        model.fit(X=X_in, y=y)
+        # Add one column so that the dataframe for prediction is
+        # different with the data for training
+        X_in["useless"] = 1
+        X_out = model.predict(X_in)
+        assert_almost_equal(X_out, X_out_expected)
+
+        with self.assertRaises(RuntimeError) as e:
+            to_onnx(model, X_in)
+            self.assertIn('ColumnTransformer', str(e))
+
 
 if __name__ == "__main__":
     # import logging
