@@ -4,7 +4,7 @@
 Tests scikit-learn's tfidf converter.
 """
 import unittest
-from distutils.version import StrictVersion
+import packaging.version as pv
 import copy
 import numpy
 from numpy.testing import assert_almost_equal
@@ -22,22 +22,22 @@ except ImportError:
     apply_less = None
 from skl2onnx import convert_sklearn
 from skl2onnx.common.data_types import StringTensorType, FloatTensorType
-import onnx
-import onnxruntime
+from onnxruntime import __version__ as ort_version
 from onnxruntime import InferenceSession
 from test_utils import dump_data_and_model, TARGET_OPSET
 
 
+ort_version = '.'.join(ort_version.split('.')[:2])
+
+
 class TestSklearnTfidfVectorizer(unittest.TestCase):
 
     def get_options(self):
         return {TfidfVectorizer: {"tokenexp": None}}
 
+    @unittest.skipIf(TARGET_OPSET < 10, reason="not available")
     @unittest.skipIf(
-        StrictVersion(onnx.__version__) <= StrictVersion("1.4.1"),
-        reason="Requires opset 9.")
-    @unittest.skipIf(
-        StrictVersion(onnxruntime.__version__) <= StrictVersion("0.3.0"),
+        pv.Version(ort_version) <= pv.Version("0.3.0"),
         reason="Requires opset 9.")
     def test_model_tfidf_vectorizer11(self):
         corpus = numpy.array([
@@ -57,20 +57,15 @@ class TestSklearnTfidfVectorizer(unittest.TestCase):
             corpus,
             vect,
             model_onnx,
-            basename="SklearnTfidfVectorizer11-OneOff-SklCol",
-            allow_failure="StrictVersion(onnxruntime.__version__)"
-                          " <= StrictVersion('0.4.0')",
-        )
+            basename="SklearnTfidfVectorizer11-OneOff-SklCol")
 
         sess = InferenceSession(model_onnx.SerializeToString())
         res = sess.run(None, {'input': corpus.ravel()})[0]
         assert res.shape == (4, 9)
 
+    @unittest.skipIf(TARGET_OPSET < 10, reason="not available")
     @unittest.skipIf(
-        StrictVersion(onnx.__version__) <= StrictVersion("1.4.1"),
-        reason="Requires opset 9.")
-    @unittest.skipIf(
-        StrictVersion(onnxruntime.__version__) <= StrictVersion("0.3.0"),
+        pv.Version(ort_version) <= pv.Version("0.3.0"),
         reason="Requires opset 9.")
     def test_model_tfidf_vectorizer11_nolowercase(self):
         corpus = numpy.array([
@@ -90,18 +85,13 @@ class TestSklearnTfidfVectorizer(unittest.TestCase):
             corpus,
             vect,
             model_onnx,
-            basename="SklearnTfidfVectorizer11NoL-OneOff-SklCol",
-            allow_failure="StrictVersion(onnxruntime.__version__)"
-                          " <= StrictVersion('0.4.0')",
-        )
+            basename="SklearnTfidfVectorizer11NoL-OneOff-SklCol")
 
         sess = InferenceSession(model_onnx.SerializeToString())
         res = sess.run(None, {'input': corpus.ravel()})[0]
         assert res.shape == (4, 11)
 
-    @unittest.skipIf(
-        StrictVersion(onnxruntime.__version__) <= StrictVersion("0.4.1"),
-        reason="Requires new onnxruntime.")
+    @unittest.skipIf(TARGET_OPSET < 10, reason="not available")
     @unittest.skipIf(
         ColumnTransformer is None,
         reason="Requires newer scikit-learn")
@@ -128,9 +118,7 @@ class TestSklearnTfidfVectorizer(unittest.TestCase):
         exp = model.transform(corpus)
         assert_almost_equal(res, exp)
 
-    @unittest.skipIf(
-        StrictVersion(onnx.__version__) <= StrictVersion("1.4.1"),
-        reason="Requires opset 9.")
+    @unittest.skipIf(TARGET_OPSET < 10, reason="not available")
     def test_model_tfidf_vectorizer11_empty_string_case1(self):
         corpus = numpy.array([
             'This is the first document.',
@@ -151,13 +139,9 @@ class TestSklearnTfidfVectorizer(unittest.TestCase):
         dump_data_and_model(
             corpus[2:], vect, model_onnx,
             basename="SklearnTfidfVectorizer11EmptyStringSepCase1-"
-                     "OneOff-SklCol",
-            allow_failure="StrictVersion(onnxruntime.__version__)"
-                          " <= StrictVersion('0.4.0')")
+                     "OneOff-SklCol")
 
-    @unittest.skipIf(
-        StrictVersion(onnx.__version__) <= StrictVersion("1.4.1"),
-        reason="Requires opset 9.")
+    @unittest.skipIf(TARGET_OPSET < 10, reason="not available")
     def test_model_tfidf_vectorizer11_empty_string_case2(self):
         corpus = numpy.array([
             "This is the first document.",
@@ -177,14 +161,9 @@ class TestSklearnTfidfVectorizer(unittest.TestCase):
             corpus,
             vect,
             model_onnx,
-            basename="SklearnTfidfVectorizer11EmptyString-OneOff-SklCol",
-            allow_failure="StrictVersion(onnxruntime.__version__)"
-                          " <= StrictVersion('0.4.0')",
-        )
+            basename="SklearnTfidfVectorizer11EmptyString-OneOff-SklCol")
 
-    @unittest.skipIf(
-        StrictVersion(onnx.__version__) <= StrictVersion("1.4.1"),
-        reason="Requires opset 9.")
+    @unittest.skipIf(TARGET_OPSET < 10, reason="not available")
     def test_model_tfidf_vectorizer11_out_vocabulary(self):
         corpus = numpy.array([
             "This is the first document.",
@@ -209,14 +188,9 @@ class TestSklearnTfidfVectorizer(unittest.TestCase):
             corpus,
             vect,
             model_onnx,
-            basename="SklearnTfidfVectorizer11OutVocab-OneOff-SklCol",
-            allow_failure="StrictVersion(onnxruntime.__version__)"
-                          " <= StrictVersion('0.4.0')",
-        )
+            basename="SklearnTfidfVectorizer11OutVocab-OneOff-SklCol")
 
-    @unittest.skipIf(
-        StrictVersion(onnx.__version__) <= StrictVersion("1.4.1"),
-        reason="Requires opset 9.")
+    @unittest.skipIf(TARGET_OPSET < 10, reason="not available")
     def test_model_tfidf_vectorizer22(self):
         corpus = numpy.array([
             "This is the first document.",
@@ -235,14 +209,9 @@ class TestSklearnTfidfVectorizer(unittest.TestCase):
             corpus,
             vect,
             model_onnx,
-            basename="SklearnTfidfVectorizer22-OneOff-SklCol",
-            allow_failure="StrictVersion(onnxruntime.__version__)"
-                          " <= StrictVersion('0.4.0')",
-        )
+            basename="SklearnTfidfVectorizer22-OneOff-SklCol")
 
-    @unittest.skipIf(
-        StrictVersion(onnx.__version__) <= StrictVersion("1.4.1"),
-        reason="Requires opset 9.")
+    @unittest.skipIf(TARGET_OPSET < 10, reason="not available")
     def test_model_tfidf_vectorizer21(self):
         corpus = numpy.array(["AA AA", "AA AA BB"]).reshape((2, 1))
         vect = TfidfVectorizer(ngram_range=(1, 2), norm=None)
@@ -256,14 +225,9 @@ class TestSklearnTfidfVectorizer(unittest.TestCase):
             corpus,
             vect,
             model_onnx,
-            basename="SklearnTfidfVectorizer22S-OneOff-SklCol",
-            allow_failure="StrictVersion(onnxruntime.__version__)"
-                          " <= StrictVersion('0.4.0')",
-        )
+            basename="SklearnTfidfVectorizer22S-OneOff-SklCol")
 
-    @unittest.skipIf(
-        StrictVersion(onnx.__version__) <= StrictVersion("1.4.1"),
-        reason="Requires opset 9.")
+    @unittest.skipIf(TARGET_OPSET < 10, reason="not available")
     def test_model_tfidf_vectorizer12(self):
         corpus = numpy.array([
             "This is the first document.",
@@ -282,14 +246,9 @@ class TestSklearnTfidfVectorizer(unittest.TestCase):
             corpus,
             vect,
             model_onnx,
-            basename="SklearnTfidfVectorizer22-OneOff-SklCol",
-            allow_failure="StrictVersion(onnxruntime.__version__)"
-                          " <= StrictVersion('0.4.0')",
-        )
+            basename="SklearnTfidfVectorizer22-OneOff-SklCol")
 
-    @unittest.skipIf(
-        StrictVersion(onnx.__version__) <= StrictVersion("1.4.1"),
-        reason="Requires opset 9.")
+    @unittest.skipIf(TARGET_OPSET < 10, reason="not available")
     def test_model_tfidf_vectorizer12_normL1(self):
         corpus = numpy.array([
             "This is the first document.",
@@ -307,14 +266,9 @@ class TestSklearnTfidfVectorizer(unittest.TestCase):
             corpus,
             vect,
             model_onnx,
-            basename="SklearnTfidfVectorizer22L1-OneOff-SklCol",
-            allow_failure="StrictVersion(onnxruntime.__version__)"
-                          " <= StrictVersion('0.4.0')",
-        )
+            basename="SklearnTfidfVectorizer22L1-OneOff-SklCol")
 
-    @unittest.skipIf(
-        StrictVersion(onnx.__version__) <= StrictVersion("1.4.1"),
-        reason="Requires opset 9.")
+    @unittest.skipIf(TARGET_OPSET < 10, reason="not available")
     def test_model_tfidf_vectorizer12_normL2(self):
         corpus = numpy.array([
             "This is the first document.",
@@ -333,14 +287,9 @@ class TestSklearnTfidfVectorizer(unittest.TestCase):
             corpus,
             vect,
             model_onnx,
-            basename="SklearnTfidfVectorizer22L2-OneOff-SklCol",
-            allow_failure="StrictVersion(onnxruntime.__version__)"
-                          " <= StrictVersion('0.4.0')",
-        )
+            basename="SklearnTfidfVectorizer22L2-OneOff-SklCol")
 
-    @unittest.skipIf(
-        StrictVersion(onnx.__version__) <= StrictVersion("1.4.1"),
-        reason="Requires opset 9.")
+    @unittest.skipIf(TARGET_OPSET < 10, reason="not available")
     def test_model_tfidf_vectorizer13(self):
         corpus = numpy.array([
             "This is the first document.",
@@ -359,14 +308,9 @@ class TestSklearnTfidfVectorizer(unittest.TestCase):
             corpus,
             vect,
             model_onnx,
-            basename="SklearnTfidfVectorizer13-OneOff-SklCol",
-            allow_failure="StrictVersion(onnxruntime.__version__)"
-                          " <= StrictVersion('0.4.0')",
-        )
+            basename="SklearnTfidfVectorizer13-OneOff-SklCol")
 
-    @unittest.skipIf(
-        StrictVersion(onnx.__version__) <= StrictVersion("1.4.1"),
-        reason="Requires opset 9.")
+    @unittest.skipIf(TARGET_OPSET < 10, reason="not available")
     def test_model_tfidf_vectorizer11parenthesis_class(self):
         corpus = numpy.array([
             "This is the first document.",
@@ -397,14 +341,9 @@ class TestSklearnTfidfVectorizer(unittest.TestCase):
             corpus,
             vect,
             model_onnx,
-            basename="SklearnTfidfVectorizer11ParenthesisClass-OneOff-SklCol",
-            allow_failure="StrictVersion(onnxruntime.__version__)"
-                          " <= StrictVersion('0.4.0')",
-        )
+            basename="SklearnTfidfVectorizer11ParenthesisClass-OneOff-SklCol")
 
-    @unittest.skipIf(
-        StrictVersion(onnx.__version__) <= StrictVersion("1.4.1"),
-        reason="Requires opset 9.")
+    @unittest.skipIf(TARGET_OPSET < 10, reason="not available")
     def test_model_tfidf_vectorizer11_idparenthesis_id(self):
         corpus = numpy.array([
             "This is the first document.",
@@ -450,13 +389,9 @@ class TestSklearnTfidfVectorizer(unittest.TestCase):
             corpus,
             vect,
             model_onnx,
-            basename="SklearnTfidfVectorizer11ParenthesisId-OneOff-SklCol",
-            allow_failure="StrictVersion(onnxruntime.__version__)"
-                          " <= StrictVersion('0.4.0')")
+            basename="SklearnTfidfVectorizer11ParenthesisId-OneOff-SklCol")
 
-    @unittest.skipIf(
-        StrictVersion(onnx.__version__) <= StrictVersion("1.4.1"),
-        reason="Requires opset 9.")
+    @unittest.skipIf(TARGET_OPSET < 10, reason="not available")
     def test_model_tfidf_vectorizer_binary(self):
         corpus = numpy.array([
             "This is the first document.",
@@ -475,16 +410,11 @@ class TestSklearnTfidfVectorizer(unittest.TestCase):
             corpus,
             vect,
             model_onnx,
-            basename="SklearnTfidfVectorizerBinary-OneOff-SklCol",
-            allow_failure="StrictVersion(onnxruntime.__version__)"
-                          " <= StrictVersion('0.4.0')",
-        )
+            basename="SklearnTfidfVectorizerBinary-OneOff-SklCol")
 
+    @unittest.skipIf(TARGET_OPSET < 10, reason="not available")
     @unittest.skipIf(
-        StrictVersion(onnx.__version__) <= StrictVersion("1.4.1"),
-        reason="Requires opset 9.")
-    @unittest.skipIf(
-        StrictVersion(onnxruntime.__version__) <= StrictVersion("0.3.0"),
+        pv.Version(ort_version) <= pv.Version("0.3.0"),
         reason="Requires opset 9.")
     def test_model_tfidf_vectorizer11_64(self):
         corpus = numpy.array([
@@ -504,10 +434,7 @@ class TestSklearnTfidfVectorizer(unittest.TestCase):
             corpus,
             vect,
             model_onnx,
-            basename="SklearnTfidfVectorizer1164-OneOff-SklCol",
-            allow_failure="StrictVersion(onnxruntime.__version__)"
-                          " <= StrictVersion('0.4.0')",
-        )
+            basename="SklearnTfidfVectorizer1164-OneOff-SklCol")
 
         sess = InferenceSession(model_onnx.SerializeToString())
         res = sess.run(None, {'input': corpus.ravel()})[0]
@@ -515,11 +442,9 @@ class TestSklearnTfidfVectorizer(unittest.TestCase):
 
     @unittest.skipIf(
         apply_less is None, reason="onnxconverter-common too old")
+    @unittest.skipIf(TARGET_OPSET < 10, reason="not available")
     @unittest.skipIf(
-        StrictVersion(onnx.__version__) <= StrictVersion("1.4.1"),
-        reason="Requires opset 9.")
-    @unittest.skipIf(
-        StrictVersion(onnxruntime.__version__) < StrictVersion("1.3.0"),
+        pv.Version(ort_version) < pv.Version("1.3.0"),
         reason="Requires opset 9.")
     def test_tfidf_svm(self):
         data = [
@@ -550,11 +475,9 @@ class TestSklearnTfidfVectorizer(unittest.TestCase):
         res = sess.run(None, {'input': embeddings})[0]
         assert_almost_equal(exp, res)
 
+    @unittest.skipIf(TARGET_OPSET < 10, reason="not available")
     @unittest.skipIf(
-        StrictVersion(onnx.__version__) <= StrictVersion("1.5.0"),
-        reason="Requires opset 10.")
-    @unittest.skipIf(
-        StrictVersion(onnxruntime.__version__) <= StrictVersion("1.0.0"),
+        pv.Version(ort_version) <= pv.Version("1.0.0"),
         reason="Requires opset 10.")
     def test_model_tfidf_vectorizer_nan(self):
         corpus = numpy.array([
@@ -577,6 +500,29 @@ class TestSklearnTfidfVectorizer(unittest.TestCase):
         assert res.shape == (4, 9)
         assert numpy.isnan(res[0, 0])
 
+    @unittest.skipIf(TARGET_OPSET < 9, reason="not available")
+    def test_model_tfidf_vectorizer11_custom_vocabulary(self):
+        corpus = numpy.array([
+            "This is the first document.",
+            "This document is the second document.",
+            "And this is the third one.",
+            "Is this the first document?",
+        ]).reshape((4, 1))
+        vc = ["first", "second", "third", "document", "this"]
+        vect = TfidfVectorizer(ngram_range=(1, 1), norm=None, vocabulary=vc)
+        vect.fit(corpus.ravel())
+        self.assertFalse(hasattr(vect, "stop_words_"))
+        model_onnx = convert_sklearn(vect, "TfidfVectorizer",
+                                     [("input", StringTensorType())],
+                                     options=self.get_options(),
+                                     target_opset=TARGET_OPSET)
+        self.assertTrue(model_onnx is not None)
+        dump_data_and_model(
+            corpus,
+            vect,
+            model_onnx,
+            basename="SklearnTfidfVectorizer11CustomVocab-OneOff-SklCol")
+
 
 if __name__ == "__main__":
     unittest.main()
